==> kadu_0.5.0.orig.tar.gz: kadu/modules/sms/translations/sms_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>SMS options</source>
        <translation>SMS-Eigenschaften</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Benutze eingebautes SMS-Programm</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Eigenes SMS-Programm</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>SMS-Formatierung</translation>
    </message>
    <message>
        <source>Check this box if your sms application doesn&apos;t understand arguments: number &quot;message&quot;
Arguments should be separated with spaces. %n argument is converted to number, %m to message</source>
        <translation>Wähle das Kästchen an, wenn dein SMS-Programm die Argumente: Tel. &quot;Nachricht&quot;
nicht versteht. Gib hier die Argumente ein, getrennt mit Komma. %n=Tel.; %m=Nachricht</translation>
    </message>
    <message>
        <source>Gateways priority</source>
        <translation>Priorität der gateways</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>nach oben</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>nach unten</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>SMS Nick</translation>
    </message>
</context>
<context>
    <name>Sms</name>
    <message>
        <source>Recipient</source>
        <translation>Empfänger</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Sende</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
    <message>
        <source>SMS error</source>
        <translation>SMS-Sendefehler</translation>
    </message>
    <message>
        <source>Sms application was not specified. Visit the configuration section</source>
        <translation>Programm zum Verschicken von SMS nicht angegeben. Schauen Sie in den Einstellungen nach</translation>
    </message>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Konnte das SMS-Programm nicht starten</translation>
    </message>
    <message>
        <source>SMS sent</source>
        <translation>SMS gesendet</translation>
    </message>
    <message>
        <source>The process exited normally. The SMS should be on its way</source>
        <translation>Das Versenden ist gelungen. Die SMS ist unterwegs</translation>
    </message>
    <message>
        <source>SMS not sent</source>
        <translation>SMS nicht verschickt</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Versenden unerwartet beendet. Die SMS wurde wahrscheinlich nicht versandt</translation>
    </message>
    <message>
        <source>The SMS was sent and should be on its way</source>
        <translation>Die SMS wurde versandt und ist unterwegs</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Unterschrift</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>SMS im Verlauf speichern</translation>
    </message>
</context>
<context>
    <name>SmsGateway</name>
    <message>
        <source>Network error. Provider gateway page is probably unavailable</source>
        <translation>Der angegebene SMS-Gateway ist wahrscheinlich nicht erreichbar</translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Lese den Text vom Bild ab und gib ihn hier ein:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>SmsSender</name>
    <message>
        <source>Mobile number is incorrect</source>
        <translation>Falsche Telefonnummer</translation>
    </message>
    <message>
        <source>Mobile number is incorrect or gateway is not available</source>
        <translation>Die Nummer des Handys ist falsch oder gateway ist unerreichbar</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation>Unterschrift darf nicht leer sein</translation>
    </message>
</context>
<context>
    <name>SmsSlots</name>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/sms/translations/sms_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick-Name</translation>
    </message>
    <message>
        <source>SMS Nick</source>
        <translation>SMS-Nick-Name</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Programm</translation>
    </message>
    <message>
        <source>Use built-in SMS application</source>
        <translation>Benutze eungebautes Programm</translation>
    </message>
    <message>
        <source>Custom SMS application</source>
        <translation>Eigenes SMS-Programm</translation>
    </message>
    <message>
        <source>Use SMS custom string</source>
        <translation>Benutze eigene SMS-Zeichenkette</translation>
    </message>
    <message>
        <source>Check this box if your sms application doesn&apos;t understand arguments: number &amp;message&amp;
Arguments should be separated with spaces. %n argument is converted to number, %m to message</source>
        <translation>Markieren Sie hier, wenn Ihr Programm für SMS die Agrumente nicht versteht: Nummer &amp;Nachricht&amp;
Argumente werder durch Leerzeichen getrennt. %n Argumente werden in Nummer, %m in Nachricht umgewandelt</translation>
    </message>
    <message>
        <source>SMS custom string</source>
        <translation>Eigene SMS-Zeichenkette</translation>
    </message>
    <message>
        <source>Gateways</source>
        <translation>SMS-Server</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kürzel</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
</context>
<context>
    <name>Sms</name>
    <message>
        <source>Recipient</source>
        <translation>Empfänger</translation>
    </message>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
    <message>
        <source>Sms application was not specified. Visit the configuration section</source>
        <translation>Programm zum Verschicken von SMS nicht angegeben. Schauen Sie in den Einstellungen nach</translation>
    </message>
    <message>
        <source>Could not spawn child process. Check if the program is functional</source>
        <translation>Konnte das SMS-Programm nicht starten</translation>
    </message>
    <message>
        <source>The process exited normally. The SMS should be on its way</source>
        <translation>Das Versenden ist gelungen. Die SMS ist unterwegs</translation>
    </message>
    <message>
        <source>The process exited abnormally. The SMS may not be sent</source>
        <translation>Versenden unerwartet beendet. Die SMS wurde wahrscheinlich nicht versandt</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Unterschrift</translation>
    </message>
    <message>
        <source>Save SMS in history</source>
        <translation>SMS im Verlauf speichern</translation>
    </message>
    <message>
        <source>The SMS was sent and should be on its way.
Do you want to send next message?</source>
        <translation>Die SMS wurde gesendet und ist auf dem Weg
Wollen Sie eine weitere Nachricht senden?</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Senden</translation>
    </message>
</context>
<context>
    <name>SmsConfigurationUiHandler</name>
    <message>
        <source>Send SMS</source>
        <translation>Sende SMS</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>nach oben</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>nach unten</translation>
    </message>
    <message>
        <source>Gateways priorites</source>
        <translation>Priorität der Gateways</translation>
    </message>
</context>
<context>
    <name>SmsGateway</name>
    <message>
        <source>Network error. Provider gateway page is probably unavailable</source>
        <translation>Der angegebene SMS-Gateway ist wahrscheinlich nicht erreichbar</translation>
    </message>
</context>
<context>
    <name>SmsImageDialog</name>
    <message>
        <source>Enter text from the picture:</source>
        <translation>Lese den Text vom Bild ab und gib ihn hier ein:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>SmsSender</name>
    <message>
        <source>Mobile number is incorrect</source>
        <translation>Falsche Telefonnummer</translation>
    </message>
    <message>
        <source>Mobile number is incorrect or gateway is not available</source>
        <translation>Die Nummer des Handys ist falsch oder gateway ist unerreichbar</translation>
    </message>
    <message>
        <source>Signature can&apos;t be empty</source>
        <translation>Unterschrift darf nicht leer sein</translation>
    </message>
</context>
</TS>
